aboutsummaryrefslogtreecommitdiffstats
path: root/actionpack/test/dispatch/session
diff options
context:
space:
mode:
authorSantiago Pastorino <santiago@wyeworks.com>2013-04-02 17:02:02 -0700
committerSantiago Pastorino <santiago@wyeworks.com>2013-04-02 17:02:02 -0700
commitac6fc606213f591f8e2c249b144843354c69af3c (patch)
treefe5249768ce475e0f19ae7213fa51b09d76f1989 /actionpack/test/dispatch/session
parente130e96f8be3f56d5e8878b6a05259f70d9292b7 (diff)
parent7c7a42734406c4f1d402d32ff0b1b916545d0da0 (diff)
downloadrails-ac6fc606213f591f8e2c249b144843354c69af3c.tar.gz
rails-ac6fc606213f591f8e2c249b144843354c69af3c.tar.bz2
rails-ac6fc606213f591f8e2c249b144843354c69af3c.zip
Merge pull request #10061 from trevorturk/dummy-key-generator-rename
Rename DummyKeyGenerator -> LegacyKeyGenerator
Diffstat (limited to 'actionpack/test/dispatch/session')
-rw-r--r--actionpack/test/dispatch/session/cookie_store_test.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/actionpack/test/dispatch/session/cookie_store_test.rb b/actionpack/test/dispatch/session/cookie_store_test.rb
index d8bf22dec8..bd05e008b3 100644
--- a/actionpack/test/dispatch/session/cookie_store_test.rb
+++ b/actionpack/test/dispatch/session/cookie_store_test.rb
@@ -1,12 +1,12 @@
require 'abstract_unit'
require 'stringio'
# FIXME remove DummyKeyGenerator and this require in 4.1
require 'active_support/key_generator'
class CookieStoreTest < ActionDispatch::IntegrationTest
SessionKey = '_myapp_session'
SessionSecret = 'b3c631c314c0bbca50c1b2843150fe33'
- Generator = ActiveSupport::DummyKeyGenerator.new(SessionSecret)
+ Generator = ActiveSupport::LegacyKeyGenerator.new(SessionSecret)
Verifier = ActiveSupport::MessageVerifier.new(SessionSecret, :digest => 'SHA1')
SignedBar = Verifier.generate(:foo => "bar", :session_id => SecureRandom.hex(16))
@@ -1,12 +1,12 @@
require 'abstract_unit'
require 'stringio'
-# FIXME remove DummyKeyGenerator and this require in 4.1
+# FIXME remove LegacyKeyGenerator and this require in 4.1
require 'active_support/key_generator'
class CookieStoreTest < ActionDispatch::IntegrationTest